@@ -1,7 +1,8 @@
 package Acme::MyFirstModule::DRZIGMAN;
 
 use 5.006;
-use strict # this is a syntax error that should cause the tests to fail
+
+use strict;
 use warnings FATAL => 'all';
 
 =head1 NAME
@@ -14,7 +15,7 @@ Version 0.01
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 
 =head1 SYNOPSIS
